%%%%%%%% This function solves the ligation reaction with EDC 
%%%%%%%% during temperature oscillations between long cold incubations 
%%%%%%%% and short hot spikes over large number of cycles

function [t_array, replicate_ab, all_a, all_b, all_A, all_B, aandab, a, a_star] = ...
    function_solve_system(t_h, t_c, n, m, initial_conditions, ...
    modif, ligon, soff_l, son_l, loff_l, lon_l, soff_h, son_h, loff_h, lon_h,...
    dil, feed, options)

tic

ligon_l = ligon;
ligon_h = ligon;
t_start = 0;
t_end = t_c;

for s = 1:n 
    
    [t,y] = ode15s(@ligationEDC_system_of_eqs, [t_start,t_end], initial_conditions, options, ...
    soff_l, son_l, loff_l, lon_l, ligon_l, 0, 0, modif);

    t_start = t_end;
    t_end = t_end+t_h;

    initial_conditions = [y(end,1) y(end,2) y(end,3) y(end,4) y(end,5)...
        y(end,6) y(end,7) y(end,8) y(end,9) y(end,10) y(end,11)...
        y(end,12) y(end,13) y(end,14) y(end,15) y(end,16) y(end,17)...
        y(end,18) y(end,19) y(end,20) y(end,21) y(end,22) y(end,23)]; 
    
    %%%% Now I will switch off feeding/dilution for steps when there should
    %%%% not be any
    if mod(s,m) == 0   
        [t1,y1] = ode15s(@ligationEDC_system_of_eqs, [t_start,t_end], initial_conditions, options, ...
        soff_h, son_h, loff_h, lon_h, ligon_h, dil, feed, modif);
    else 
        [t1,y1] = ode15s(@ligationEDC_system_of_eqs, [t_start,t_end], initial_conditions, options, ...
        soff_h, son_h, loff_h, lon_h, ligon_h, 0, 0, modif);
    end

    t_final{1,s} = t;
    t_final{2,s} = t1;
    y_final{1,s} = y;
    y_final{2,s} = y1;

    t_start = t_end;
    t_end = t_end+t_c;
    
    initial_conditions = [y1(end,1) y1(end,2) y1(end,3) y1(end,4) y1(end,5)...
        y1(end,6) y1(end,7) y1(end,8) y1(end,9) y1(end,10) y1(end,11)...
        y1(end,12) y1(end,13) y1(end,14) y1(end,15) y1(end,16) y1(end,17)...
        y1(end,18) y1(end,19) y1(end,20) y1(end,21) y1(end,22) y1(end,23)];
    
    s

end

t_array = vertcat(t_final{1,1},t_final{2,1});
y_array = vertcat(y_final{1,1},y_final{2,1});

if n>1
    for s = 2:n
    
        t_array = vertcat (t_array,t_final{1,s},t_final{2,s});
        y_array = vertcat (y_array,y_final{1,s},y_final{2,s});
    
    end
end
% Fragments
a  =  y_array(:,1); 
b  =  y_array(:,2); 
A  =  y_array(:,3); 
B  =  y_array(:,4);
a_star =  y_array(:,5);
B_star =  y_array(:,6);

% Templates
ab = y_array(:,7); 
BA = y_array(:,8); 

% Double stranded template-replicate product; "x" - hybridization
abxBA = y_array(:,9); 

% Fragments hybridyzed on the templates
abA  = y_array(:,10); 
abB  = y_array(:,11); 
BAa  = y_array(:,12); 
BAb  = y_array(:,13);
abB_star = y_array(:,14);
BAa_star = y_array(:,15);

% Two fragments hybridyzes but not ligated on the template
a_bxBA  = y_array(:,16); 
abxB_A  = y_array(:,17);
a_star_bxBA = y_array(:,18); 
abxB_star_A = y_array(:,19);

% Hybridyzed fragments
axA = y_array(:,20); 
bxB = y_array(:,21);
a_starxA = y_array(:,22); 
bxB_star = y_array(:,23);

all_a = a+a_star+ab+abxBA+abA+abB+abB_star+BAa+BAa_star+a_bxBA+a_star_bxBA+abxB_A+abxB_star_A+axA+a_starxA;
all_b = b+ab+abxBA+abA+abB+abB_star+BAb+a_bxBA+a_star_bxBA+abxB_A+abxB_star_A+bxB+bxB_star;
all_B = B+B_star+BA+abxBA+BAa+BAb+BAa_star+abB+abB_star+a_bxBA+a_star_bxBA+abxB_A+abxB_star_A+bxB+bxB_star;
all_A = A+BA+abxBA+BAa+BAb+BAa_star+abA+a_bxBA+a_star_bxBA+abxB_A+abxB_star_A+axA+a_starxA;
aandab = a+ab+a_star;
replicate_ab = ab+abxBA+abA+abB+abB_star+abxB_A+abxB_star_A;

toc %gives out value in workspace