% System of equations describing the ligation system with EDC %

function dydt = ligationEDC_system_of_eqs(t,y,soff,son,loff,lon,ligon,...
                            dil,feed,modif)

%Fragments
a=y(1); 
b=y(2); 
A=y(3); 
B=y(4); 
a_star=y(5); % Fragment 'a' after being permanently modified by EDC
B_star=y(6); % Fragment 'B' after being permanently modified by EDC

%Templates
ab=y(7); 
BA=y(8); 

%Double stranded template-replicate product; "x" denotes hybridization
abxBA=y(9); 

%Fragments hybridyzed on the templates
abA=y(10); 
abB=y(11); 
BAa=y(12); 
BAb=y(13);
abB_star=y(14);
BAa_star=y(15);

%Two fragments hybridyzed on the templates but not ligated yet
a_bxBA=y(16); 
abxB_A=y(17);
a_star_bxBA=y(18);
abxB_star_A=y(19);

%Hybridyzed fragments
axA=y(20); bxB=y(21);
a_starxA=y(22); bxB_star=y(23);

dydt=zeros(23,1);

%Fragments
dydt(1) = -dil*a + feed - modif*a...
                        + soff*axA     - son*a*A... 
                        + soff*BAa     - son*BA*a...
                        + soff*a_bxBA  - son*BAb*a...
                        + son*BAa*ab*0;
                    
dydt(2) = -dil*b + feed...
                        + soff*bxB     - son*b*B... 
                        + soff*BAb     - son*BA*b...
                        + soff*a_bxBA  - son*BAa*b...
                        + son*BAb*ab*0 ...
                        + soff*bxB_star    - son*b*B_star...
                        + soff*a_star_bxBA - son*BAa_star*b;
                    
dydt(3) = -dil*A + feed...
                        + soff*axA     - son*a*A... 
                        + soff*abA     - son*ab*A...
                        + soff*abxB_A  - son*abB*A...
                        + son*abA*BA*0 ...
                        + soff*a_starxA    - son*a_star*A...
                        + soff*abxB_star_A - son*abB_star*A;                  
                    
dydt(4) = -dil*B + feed - modif*B...
                        + soff*bxB     - son*b*B... 
                        + soff*abB     - son*ab*B...
                        + soff*abxB_A  - son*abA*B...
                        + son*abB*BA*0;    
                    
dydt(5) = -dil*a_star + modif*a...
                        + soff*a_starxA     - son*a_star*A...
                        + soff*BAa_star     - son*BA*a_star...
                        + soff*a_star_bxBA  - son*BAb*a_star...
                        + son*BAa_star*ab*0;
                    
dydt(6) = -dil*B_star + modif*B...
                        + soff*bxB_star     - son*b*B_star...
                        + soff*abB_star    - son*ab*B_star...
                        + soff*abxB_star_A - son*abA*B_star...
                        + son*abB_star*BA*0;

%Templates
dydt(7) = -dil*ab...
               + soff*abA   - son*ab*A...
               + soff*abB   - son*ab*B...
               + loff*abxBA - lon*ab*BA...
               - (son*BAa*ab + son*BAa_star*ab + son*BAb*ab)*0 ...
               + soff*abB_star  - son*ab*B_star;           
                           
dydt(8) = -dil*BA...
               + soff*BAb   - son*BA*b...
               + soff*BAa   - son*BA*a...
               + loff*abxBA - lon*ab*BA...
               - (son*abA*BA + son*abB*BA + son*abB_star*BA)*0 ...
               + soff*BAa_star  - son*BA*a_star;
              
% Double stranded template-replicate product
% 100% ligation efficiency with EDC is assumed
dydt(9) = -dil*abxBA...
               + lon*ab*BA  - loff*abxBA...
               + ligon*a_bxBA...   
               + ligon*abxB_A...
               + (son*BAa*ab + son*BAa_star*ab + son*BAb*ab)*0 ...
               + (son*abA*BA + son*abB*BA + son*abB_star*BA)*0;
           
%Fragments hybridyzed on the templates
dydt(10)  = -dil*abA...
               + son*ab*A       - soff*abA...
               + soff*abxB_A    - son*abA*B...
               - son*abA*BA*0 ...
               + soff*abxB_star_A   - son*abA*B_star;              
                
dydt(11)  = -dil*abB - modif*abB...
               + son*ab*B       - soff*abB...
               + soff*abxB_A    - son*abB*A;
               - son*abB*BA*0;             
                
dydt(12) = -dil*BAa - modif*BAa...
               + son*BA*a       - soff*BAa...
               + soff*a_bxBA    - son*BAa*b...
               - son*BAa*ab*0;                
                
dydt(13) = -dil*BAb...
               + son*BA*b       - soff*BAb...
               + soff*a_bxBA    - son*BAb*a...
               - son*BAb*ab*0 ...
               + soff*a_star_bxBA   - son*BAb*a_star; 

dydt(14) = -dil*abB_star + modif*abB...
               + son*ab*B_star      - soff*abB_star...
               + soff*abxB_star_A   - son*abB_star*A...
               - son*abB_star*BA*0;

dydt(15) = -dil*BAa_star + modif*BAa...
               + son*BA*a_star      - soff*BAa_star...
               + soff*a_star_bxBA   - son*BAa_star*b...
               - son*BAa_star*ab*0;

%Two fragments hybridyzed on the templates but not ligated yet
dydt(16) = -dil*a_bxBA - modif*a_bxBA...
               + son*BAb*a      - soff*a_bxBA...
               + son*BAa*b      - soff*a_bxBA...
               - ligon*a_bxBA;

dydt(17) = -dil*abxB_A - modif*abxB_A...
               + son*abA*B      - soff*abxB_A...
               + son*abB*A      - soff*abxB_A...
               - ligon*abxB_A;

dydt(18) = -dil*a_star_bxBA + modif*a_bxBA...
               + son*BAb*a_star     - soff*a_star_bxBA...
               + son*BAa_star*b     - soff*a_star_bxBA;

dydt(19) = -dil*abxB_star_A + modif*abxB_A...
               + son*abA*B_star     - soff*abxB_star_A...
               + son*abB_star*A     - soff*abxB_star_A;

%Hybridyzed fragments
dydt(20) = -dil*axA - modif*axA...
               + son*a*A    - soff*axA;

dydt(21) = -dil*bxB - modif*bxB...
               + son*b*B    - soff*bxB;

dydt(22) = -dil*a_starxA + modif*axA...
               + son*a_star*A   - soff*a_starxA;

dydt(23) = -dil*bxB_star + modif*bxB...
               + son*b*B_star   - soff*bxB_star;